@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -15,16 +15,33 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from copy import copy
+
+from djangode.data.autocomplete.builtins import builtins
 from djangode.data.autocomplete.namespace import Namespace
+from djangode.data.autocomplete.value import Value
 
 class Class(Namespace):
-    def __init__(self, module, name):
+    def __init__(self, module, name, type=None):
         Namespace.__init__(self, module)
 
         self.name = name
+        self.type = set([builtins.get_variable("classobj").value]) if type is None else set([type])
 
-    def get_instance(self):
-        return Instance(self)
+    def call(self):
+        return Value(Instance(self))
+
+    def copy(self):
+        c = Class(self.parent_scope, self.name)
+        c.type = set(list(self.type))
+        c.variables = copy(self.variables)
+        return c
+
+    def __eq__(self, other):
+        return self.name == other.name
+
+    def __ne__(self, other):
+        return not (self == other)
 
     def __repr__(self):
         return "<Class %s>" % (self.name, )
@@ -33,8 +50,16 @@ class Instance(Namespace):
     def __init__(self, _class):
         Namespace.__init__(self, _class)
 
-    def get_attributes(self):
-        return Namespace.get_attributes(self) + self.parent_scope.get_attributes()
+        self.type = set([_class])
+
+    def get_attributes(self, nested=False):
+        return Namespace.get_attributes(self, nested=nested) + self.parent_scope.get_attributes(nested=nested)
+
+    def __eq__(self, other):
+        return self.type == other.type
+
+    def __ne__(self, other):
+        return not (self == other)
 
     def __repr__(self):
         return "<Instance %s>" % (repr(self.parent_scope), )
