@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -25,13 +25,29 @@ builtins = Builtins()
 
 from djangode.data.autocomplete._class import Class
 from djangode.data.autocomplete.function import Function
+from djangode.data.autocomplete.value import Value
 
-int_class = Class(builtins, "int")
+type_class = Class(builtins, "type", type=True)
+type_class.type = set([type_class])
+builtins.set_variable("type", Value(type_class))
+
+func_type = Class(builtins, "callable", type=type_class)
+func_type.docstring = callable.__doc__
+builtins.set_variable("callable", Value(func_type))
+
+classobj_type = Class(builtins, "classobj", type=type_class)
+builtins.set_variable("classobj", Value(classobj_type))
+
+int_class = Class(builtins, "int", type=type_class)
 int_class.docstring = int.__doc__
-builtins.set_variable("int", int_class)
+builtins.set_variable("int", Value(int_class))
 
-string_class = Class(builtins, "str")
+string_class = Class(builtins, "str", type=type_class)
 string_class.docstring = str.__doc__
-string_class.set_variable("lower", Function(string_class, "lower"))
-string_class.set_variable("upper", Function(string_class, "upper"))
-builtins.set_variable("str", string_class)
+string_class.set_variable("lower", Value(Function(string_class, "lower")))
+string_class.set_variable("upper", Value(Function(string_class, "upper")))
+builtins.set_variable("str", Value(string_class))
+
+tuple_class = Class(builtins, "tuple", type=type_class)
+tuple_class.docstring = tuple.__doc__
+builtins.set_variable("tuple", Value(tuple_class))
