@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -15,10 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from djangode.data.autocomplete.builtins import builtins
 from djangode.data.autocomplete.namespace import Namespace
+from djangode.data.autocomplete.value import Value
 
 class Function(Namespace):
-    def __init__(self, parent_scope, name):
+    def __init__(self, parent_scope, name, tl=None):
         Namespace.__init__(self, parent_scope)
 
         self.name = name
+        self.type = set(builtins.get_variable("callable").value.type)
+        self.tl = tl
+
+    def call(self):
+        return Value()
