@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -20,7 +20,10 @@ class Variable(object):
         self.name = name
         self.value = value
 
+    def copy(self):
+        return Variable(self.name, self.value.copy())
+
     def __unicode__(self):
         return repr(self)
     def __repr__(self):
-        return "<Variable %s>" % (self.name, self.value)
+        return "<Variable %s %s>" % (self.name, self.value)
