@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -20,4 +20,5 @@ This module contains an global variables in DjangoDE.
 """
 
 project = None # pylint: disable-msg=C0103
-window = None # pylint: disable-msg=C0103
+main_window = None # pylint: disable-msg=C0103
+icon = None # pylint: disable-msg=C0103
