@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -16,3 +16,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 from autocompleter import TestAutoCompleter
+
+from gui import *
+from data import *
+from utils import *
