@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -19,7 +19,9 @@
 This module handles the loading and saving of DjangoDE settings.
 """
 
-from PyQt4 import QtCore
+from qt import QtCore, library as qt_library
+
+from config_defaults import config_defaults, config_converter
 
 CONFIG = None
 
@@ -34,12 +36,34 @@ def get_config_value(key, default=None):
     if CONFIG is None:
         _load_config()
 
-    return CONFIG.value(key, default)
+    if not CONFIG.contains(key):
+        return default if default is not None else config_defaults.get(key, None)
+
+    value = CONFIG.value(key)
+
+    converter = config_converter.get(key, lambda v: v)
+
+    # PyQt4 returns a QVariant while PySide doesn't
+    if hasattr(QtCore, "QVariant") and isinstance(value, QtCore.QVariant):
+        if value.isNull():
+            return None
+        elif value.typeName() == "QString":
+            return converter(unicode(value.toString()))
+        elif value.typeName() == "QByteArray":
+            return converter(value.toByteArray())
+        elif value.typeName() == "QStringList":
+            return converter(value.toStringList())
+        else:
+            raise ValueError, "Unknown QVariant type %s." % (value.typeName(), )
+    else:
+        return converter(value)
 
 def set_config_value(key, value):
     """Save a value into the configuration."""
     if CONFIG is None:
         _load_config()
 
-    CONFIG.setValue(key, value)
+    if qt_library == "pyqt4" and isinstance(value, tuple):
+        value = list(value)
 
+    CONFIG.setValue(key, value)
