@@ -1,4 +1,4 @@
-# DjangoDE, a integrated development environment for Django
+# DjangoDE, an integrated development environment for Django
 # Copyright (C) 2010-2011 Andrew Wilkinson
 #
 # This program is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
 
 import os
 
-from PyQt4 import QtNetwork
+from qt import QtNetwork
 
 def set_proxy():
     for key, value in os.environ.items():
